/*
 * Copyright 2016 Google, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License")
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


package com.netflix.spinnaker.config

import com.netflix.spinnaker.kork.sql.test.SqlTestUtil
import org.jooq.DSLContext
import org.springframework.boot.autoconfigure.condition.ConditionalOnProperty
import org.springframework.context.annotation.Bean
import org.springframework.context.annotation.Configuration

import javax.sql.DataSource

@Configuration
@ConditionalOnProperty("sql.enabled")
class MySQLContainerConfig {

  @Bean
  SqlTestUtil.TestDatabase testDatabase() {
    SqlTestUtil.initTcMysqlDatabase()
  }

  @Bean
  DataSource jedisPool(SqlTestUtil.TestDatabase testDatabase) {
    testDatabase.dataSource
  }

  @Bean
  DSLContext dslContext(SqlTestUtil.TestDatabase testDatabase) {
    testDatabase.context
  }
}
